@@ -150,7 +150,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "AO", "Angola" },
             { "AQ", "Ant\u00e0rtida" },
             { "AR", "Argentina" },
-            { "AS", "Samoa Nord-americana" },
+            { "AS", "Samoa Americana" },
             { "AT", "\u00c0ustria" },
             { "AU", "Austr\u00e0lia" },
             { "AW", "Aruba" },
@@ -173,12 +173,12 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "BR", "Brasil" },
             { "BS", "Bahames" },
             { "BT", "Bhutan" },
-            { "BV", "Bouvet" },
+            { "BV", "Illa Bouvet" },
             { "BW", "Botswana" },
             { "BY", "Belar\u00fas" },
             { "BZ", "Belize" },
             { "CA", "Canad\u00e0" },
-            { "CC", "Illes Cocos" },
+            { "CC", "Illes Cocos (Keeling)" },
             { "CD", "Congo - Kinshasa" },
             { "CF", "Rep\u00fablica Centreafricana" },
             { "CG", "Congo - Brazzaville" },
@@ -240,7 +240,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "GW", "Guinea Bissau" },
             { "GY", "Guyana" },
             { "HK", "Hong Kong (RAE Xina)" },
-            { "HM", "Illa Heard i Illes McDonald" },
+            { "HM", "Illes Heard i McDonald" },
             { "HN", "Hondures" },
             { "HR", "Cro\u00e0cia" },
             { "HT", "Hait\u00ed" },
@@ -294,7 +294,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "MM", "Myanmar (Birm\u00e0nia)" },
             { "MN", "Mong\u00f2lia" },
             { "MO", "Macau (RAE Xina)" },
-            { "MP", "Illes Mariannes Septentrionals" },
+            { "MP", "Illes Marianes del Nord" },
             { "MQ", "Martinica" },
             { "MR", "Maurit\u00e0nia" },
             { "MS", "Montserrat" },
@@ -339,7 +339,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "RS", "S\u00e8rbia" },
             { "RU", "R\u00fassia" },
             { "RW", "Ruanda" },
-            { "SA", "Ar\u00e0bia Saudita" },
+            { "SA", "Ar\u00e0bia Saud\u00ed" },
             { "SB", "Illes Salom\u00f3" },
             { "SC", "Seychelles" },
             { "SD", "Sudan" },
@@ -624,6 +624,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "bez", "bena" },
             { "bfd", "bafut" },
             { "bfq", "badaga" },
+            { "bgc", "haryanvi" },
             { "bgn", "balutxi occidental" },
             { "bho", "bhojpuri" },
             { "bik", "bicol" },
@@ -1183,7 +1184,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "%%1994", "ortografia resiana estandarditzada" },
             { "%%1996", "ortografia alemanya de 1996" },
             { "ar_001", "\u00e0rab est\u00e0ndard modern" },
-            { "es_419", "espanyol hispanoameric\u00e0" },
+            { "es_419", "espanyol llatinoameric\u00e0" },
             { "key.ca", "calendari" },
             { "key.cf", "format de moneda" },
             { "key.co", "ordre" },
@@ -1338,7 +1339,6 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "type.ca.japanese", "calendari japon\u00e8s" },
             { "type.cf.standard", "format de moneda est\u00e0ndard" },
             { "type.co.phonetic", "ordre fon\u00e8tic" },
-            { "type.co.reformed", "ordre reformat" },
             { "type.co.searchjl", "cerca per consonant inicial del hangul" },
             { "type.co.standard", "ordre est\u00e0ndard" },
             { "type.ms.uksystem", "sistema imperial d\u2019unitats" },
